@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2021-2022 Univention GmbH
+# Copyright 2021-2023 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -34,24 +34,27 @@
 from typing import Optional  # noqa: F401
 
 # choose a backend
-from univention.ldap_cache.cache.backend.gdbm_cache import GdbmCaches as Caches, GdbmCache as Cache, GdbmShard as Shard  # noqa: F401
-# from univention.ldap_cache.cache.backend.lmdb_cache import LmdbCaches as Caches, LmdbCache as Cache, LmdbShard as Shard
-
-from univention.ldap_cache.log import debug
+from univention.ldap_cache.cache.backend.gdbm_cache import (  # noqa: F401
+    GdbmCache as Cache, GdbmCaches as Caches, GdbmShard as Shard,
+)
 from univention.ldap_cache.cache.shard_config import shards_from_config
+from univention.ldap_cache.log import debug
+
+
+# from univention.ldap_cache.cache.backend.lmdb_cache import LmdbCaches as Caches, LmdbCache as Cache, LmdbShard as Shard
 
 
 # Singleton pattern
 def get_cache():
-	# type: () -> Caches
-	global _cache
-	if _cache is None:
-		debug('Creating the Caches instance')
-		caches = Caches()
-		for klass in shards_from_config():
-			caches.add(klass)
-		_cache = caches
-	return _cache
+    # type: () -> Caches
+    global _cache
+    if _cache is None:
+        debug('Creating the Caches instance')
+        caches = Caches()
+        for klass in shards_from_config():
+            caches.add(klass)
+        _cache = caches
+    return _cache
 
 
 _cache = None  # type: Optional[Caches]
